@@ -9,7 +9,7 @@ use FFI::Platypus::Buffer;
 use FFI::Platypus::Memory;
 use Time::FFI::tm;
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 our @EXPORT_OK = qw(asctime ctime gmtime localtime mktime strftime strptime);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -136,7 +136,6 @@ Time::FFI - libffi interface to POSIX date and time functions
   my $tm = strptime '1995-01-02 13:15:39', '%Y-%m-%d %H:%M:%S';
   my $epoch = mktime $tm;
   print "$epoch: ", strftime('%I:%M:%S %p on %B %e, %Y', $tm);
-  my $piece = $tm->to_object('Time::Piece', 1);
 
   my $tm = localtime time;
   my $datetime = $tm->to_object('DateTime', 1);
@@ -144,6 +143,11 @@ Time::FFI - libffi interface to POSIX date and time functions
   my $tm = gmtime time;
   my $moment = $tm->to_object('Time::Moment', 0);
 
+  use Time::FFI::tm;
+  my $tm = Time::FFI::tm->from_object(DateTime->now, 1);
+  my $epoch = $tm->epoch(1);
+  my $piece = $tm->to_object('Time::Piece', 1);
+
 =head1 DESCRIPTION
 
 B<Time::FFI> provides a L<libffi|FFI::Platypus> interface to POSIX date and
@@ -205,7 +209,7 @@ L<localtime_r(3)> function is used if available.
   my $epoch = mktime $tm;
 
 Returns the epoch timestamp representing the passed L<Time::FFI::tm> record
-interpreted in the local time zone. The time is interpreted from the L<tm_sec>,
+interpreted in the local time zone. The time is interpreted from the C<tm_sec>,
 C<tm_min>, C<tm_hour>, C<tm_mday>, C<tm_mon>, C<tm_year>, and C<tm_isdst>
 members of the record, ignoring the rest. DST status will be automatically
 determined if C<tm_isdst> is a negative value. The C<tm_isdst>, C<tm_wday>, and
